@@ -9,4 +9,10 @@ def smart_update_dict(dic1={},dic2={}):
                 dic1[k]=v
 def inrange(n,rg):
     if n>=rg[0] and n<= rg[1]:return True
-    return False
\ No newline at end of file
+    return False
+def split_dict(dic,keys):
+    dic2={}
+    for key in keys:
+        if key in dic.keys():
+            dic2[key]=dic[key]
+    return dic2
